module MatchMate
  describe AddressMatcher do
    context 'comparing equivalent addresses' do
      let(:address) { MatchMate::Address.new '12395 El Camino Avenue Suite 120 San Diego, CA 92130' }
      let(:other_address) { MatchMate::Address.new '12395 El Camino Ave. Ste 120 San Diego, CA 92130' }
      subject { MatchMate::AddressMatcher.new address, other_address }
      describe '#score' do
        it 'is a full match of 100' do
          expect(subject.score).to eq(100)
        end
        context 'with weights that dont add up to 100' do
          around(:each) do |example|
            address_weights = {
              address_weights: {
                road: {
                  weight: 23,
                  threshold: 80
                },
                unit: {
                  weight: 13,
                  threshold: 80
                },
                postcode: {
                  weight: 133,
                  threshold: 100
                },
                city: {
                  weight: 3,
                  threshold: 80
                },
                house_number: {
                  weight: 17,
                  threshold: 100
                }
              }
            }
            with_config address_weights do
              example.run
            end
          end
          it 'is a full match of 100' do
            expect(subject.score).to eq(100)
          end
        end
      end
    end
    context 'matching address pair examples' do
      let(:examples) do
        [
          ['12395 El Camino Real. Suite 120 San Diego, CA 92130', '12395 El Camino Real Ste 120 San Diego, CA 92130']
        ]
      end
      it 'should all match' do
        examples.each do |example|
          expect(MatchMate::AddressMatcher.new(example[0], example[1])).to be_match
        end
      end
    end
  end
end
