# Note that these examples rely on an existing appointment.
# If you want to regenerate the VCR cassettes for these examples,
# you'll need to generate a new appointment, adjust the `api_params` to match,
# and then run the `success` example before the `already_cancelled` example.
module MatchMate
  describe Address do
    context 'passing entire address as a string' do
      subject { MatchMate::Address.new '12395 El Camino Ave Ste 120 San Diego, CA 92130-12456' }

      describe '#road' do
        it 'extracts an arrayt of expandeded, normalized, lowercase core street address' do
          expect(subject.road).to include('el camino avenue')
        end
      end
      describe '#unit' do
        it 'only uses the number' do
          expect(subject.unit).to eq('120')
        end
      end
      describe '#house_number' do
        it 'extracts the house number' do
          expect(subject.house_number).to eq('12395')
        end
      end
      describe '#postcode' do
        context 'when postcode_limit is not set' do
          it 'returns the full postcode' do
            expect(subject.postcode).to eq('92130-12456')
          end
        end
        context 'when postcode_limit is set' do
          around(:each) do |example|
            with_config(postcode_limit: 5) do
              example.run
            end
          end
          it 'extracts the first digits set by limit' do
            expect(subject.postcode).to eq('92130')
          end
        end
      end
      describe '#city' do
        it 'extracts lowercase city name' do
          expect(subject.city).to eq('san diego')
        end
      end
    end
  end
end
