describe FuzzyWuzzy do
  context 'comparing single strings' do
    describe '#token_set_ratio' do
      context 'literal match' do
        subject { FuzzyWuzzy.new 'string', 'string' }
        it 'returns 100' do
          expect(subject.token_set_ratio).to eq(100)
        end
      end
      context 'comparing two nil values' do
        subject { FuzzyWuzzy.new nil, nil}
        it 'returns 100' do
          expect(subject.token_set_ratio).to eq(100)
        end
      end
      context 'literal match ignores capitalization and spaces' do
        subject { FuzzyWuzzy.new 'A  string   ', 'a stRing' }
        it 'returns 100' do
          expect(subject.token_set_ratio).to eq(100)
        end
      end
      context 'close match' do
        subject { FuzzyWuzzy.new 'swing', 'string' }
        it 'returns less than 100' do
          expect(subject.token_set_ratio).to be < 100
        end
      end
      context 'total mismatch' do
        subject { FuzzyWuzzy.new 'mash', 'pot' }
        it 'returns 0' do
          expect(subject.token_set_ratio).to eq(0)
        end
      end
    end
  end
  context 'comparing string against array of strings' do
    describe '#token_set_ratio' do
      context 'full match on one of the members' do
        subject { FuzzyWuzzy.new 'string', %w[other_string string] }
        it 'returns 100' do
          expect(subject.token_set_ratio).to eq(100)
        end
      end
      context 'close match on one of the members' do
        subject { FuzzyWuzzy.new 'string', %w[swing pot] }
        it 'returns less than 100' do
          expect(subject.token_set_ratio).to be < 100
        end
      end
      context 'total mismatch on all of the members' do
        subject { FuzzyWuzzy.new 'mash', %w[pot not] }
        it 'returns 0' do
          expect(subject.token_set_ratio).to eq(0)
        end
      end
    end
  end
  context 'comparing two arrays of strings' do
    describe '#token_set_ratio' do
      context 'full match on one of the members' do
        subject { FuzzyWuzzy.new ['a string', 'something'], ['other_string', 'a string'] }
        it 'returns 100' do
          expect(subject.token_set_ratio).to eq(100)
        end
      end
      context 'close match on one of the members' do
        subject { FuzzyWuzzy.new %w[string rack], %w[swing pot] }
        it 'returns less than 100' do
          expect(subject.token_set_ratio).to be < 100
        end
      end
      context 'total mismatch on all of the members' do
        subject { FuzzyWuzzy.new %w[mash rack], %w[pot not] }
        it 'returns 0' do
          expect(subject.token_set_ratio).to eq(0)
        end
      end
    end
  end
end
